@@ -46,11 +46,16 @@ gettext.textdomain("lubuntu-software-center")
 class LscControl:
     '''The class that control the program'''
     def __init__(self):
-        self.ui = UI.Gui(self.on_selected_category)
+        self.ui = UI.Gui(self.on_selected_category, threadingops.get_categories())
+        self.apps_model_search = Gtk.ListStore(str, str, int, str, str, int, Pango.EllipsizeMode)
+        self.installed_model_search = Gtk.ListStore(str, str, int, str, str, int, Pango.EllipsizeMode)
         #-------------------------------------------------------
         self.choosed_page = 0
         self.last_page = 0
-        self.actual_category = "All"
+        self.actual_category = "packages"
+        self.was_searching = False
+        self.startup = True
+        self.active_for_search = True
         #-------------------------------------------------------
         self.refresh_system_call()
         #-------------------------------------------------------
@@ -62,7 +67,7 @@ class LscControl:
         self.ui.install_pkgs.connect("clicked", self.on_install_pkgs)
         self.ui.remove_mai_button.connect("clicked", self.on_clear_basket)
         #-------------------------------------------------------
-        self.ui.toolbar.back.connect("clicked", self.back_home)
+        self.ui.toolbar.back.connect("clicked", self.back_to_last_page)
         self.ui.toolbar.settings.connect("clicked", self.on_show_preferences)
         #-------------------------------------------------------
         self.ui.apps_all.connect("cursor-changed", self.on_selected_available)
@@ -71,16 +76,14 @@ class LscControl:
         self.ui.apps_installed.connect("row-activated", self.on_more_info_row, 1)
         self.ui.statusbox.combo.connect("changed", self.statusbox_combo_changed)
         #-------------------------------------------------------
-        self.ui.apps_message.close.connect("clicked", lambda w: self.ui.apps_message.hide())
-        self.ui.installed_message.close.connect("clicked", lambda w: self.ui.installed_message.hide())
         self.ui.apps_message.add_remove_button.connect("clicked", self.on_install_or_remove, None)
         self.ui.installed_message.add_remove_button.connect("clicked", self.on_install_or_remove, self.ui.apps_installed)
         self.ui.apps_message.details_button.connect("clicked", self.on_more_info, 0)
         self.ui.installed_message.details_button.connect("clicked", self.on_more_info, 1)
         #-------------------------------------------------------
         self.ui.appsinfo.button.connect("clicked", self.on_install_or_remove, self.ui.apps_installed)
-        self.ui.appsinfo.back.connect("clicked", self.back_to_page)
-        self.ui.appsinfo.scrot_button.connect("clicked", self.maximize_screenshot)
+        self.ui.appsinfo.scrot_button.connect("button-press-event", self.maximize_screenshot)
+        self.ui.appsinfo.check_reviews.connect("clicked", self.download_review)
         #-------------------------------------------------------
         self.ui.no_found_button.connect("clicked", self.search_in_all)
         #-------------------------------------------------------
@@ -92,13 +95,31 @@ class LscControl:
         reposavailable = testnet()
         if(reposavailable != 0):
             notify("no-connection")
-
+            control.controller.show_scrot = False
+            control.controller.show_reviews = False
     
-    def back_to_page(self, widget):
-        self.ui.pages.change_page(self.last_page)
-        self.ui.search_pkg.set_sensitive(True)
-        self.ui.categorie_label.set_text(self.last_page_label)
-        self.ui.categorie_icon.set_from_icon_name(self.last_page_icon, Gtk.IconSize.MENU)
+    def back_to_last_page(self, widget):
+        self.ui.statusbox.installed.set_from_stock('', 1)
+        if self.last_page == 0:
+            self.was_searching = False
+            self.ui.toolbar.back.set_sensitive(False)
+            self.back_home(widget)
+        elif self.last_page == 2:
+            self.ui.statusbox.combo.set_visible(self.was_searching)
+            self.ui.toolbar.back.set_sensitive(False)
+            self.ui.pages.change_page(self.last_page)
+            self.ui.search_pkg.set_sensitive(True)
+            self.ui.categorie_label.set_text(self.last_page_label)
+            self.ui.categorie_icon.set_from_icon_name(self.last_page_icon, Gtk.IconSize.LARGE_TOOLBAR)
+        elif self.ui.pages.get_current_page() == 1:
+            self.last_page = 0
+            self.back_home(widget)
+        else:
+            self.ui.statusbox.combo.set_visible(self.was_searching)
+            self.ui.pages.change_page(self.last_page)
+            self.ui.search_pkg.set_sensitive(True)
+            self.ui.categorie_label.set_text(self.last_page_label)
+            self.ui.categorie_icon.set_from_icon_name(self.last_page_icon, Gtk.IconSize.LARGE_TOOLBAR)
     
     def on_more_info_row(self, widget, view, path, num):
         self.on_more_info(None, num)
@@ -109,26 +130,25 @@ class LscControl:
         else:
             self.ui.pages.change_page(1)
             self.category_infos = self.ui.categories_dict[self.choosed_category]
-            self.ui.categorie_icon.set_from_icon_name(self.category_infos[0], 1)
-            self.ui.categorie_label.set_text(self.choosed_category)
+            self.ui.categorie_icon.set_from_icon_name(self.category_infos[0], Gtk.IconSize.LARGE_TOOLBAR)
+            self.ui.categorie_label.set_text(self.category_infos[1])
             self.ui.pkgs_count.set_text("%s "  % len(self.ui.apps_all.model)+_("packages listed"))
             self.ui.search_pkg.set_sensitive(True)
         self.ui.installed_message.set_visible(False)
         self.ui.apps_message.set_visible(False)
-            
     
     def installed_func(self):
         if len(self.ui.apps_installed.model) == 0:
-            self.append_packages_call("allpkgs", [
+            self.append_packages_call("packages", [
             apt_pkg.CURSTATE_NOT_INSTALLED,
             apt_pkg.CURSTATE_CONFIG_FILES,
             apt_pkg.CURSTATE_HALF_CONFIGURED,
             apt_pkg.CURSTATE_HALF_INSTALLED,
             apt_pkg.CURSTATE_UNPACKED
-            ], self.ui.apps_installed.model)
-        self.ui.categorie_icon.set_from_icon_name("harddrive", 1)
+            ], self.ui.apps_installed.model, False)
+        self.ui.categorie_icon.set_from_icon_name("harddrive", Gtk.IconSize.LARGE_TOOLBAR)
         self.ui.categorie_label.set_text(_("Installed"))
-        self.actual_category = _("Installed")
+        self.actual_category = "packages"
         self.ui.pkgs_count.set_text("%s "  % len(self.ui.apps_installed.model)+_("packages listed"))
         self.ui.installed_message.set_visible(False)
         self.ui.apps_message.set_visible(False)
@@ -136,21 +156,23 @@ class LscControl:
     
     def on_selected_category(self, widget):
         '''Handle the change of section'''
+        print self.ui.categories_button_dict[widget]
         self.ui.pages.can_home = True
         self.ui.toolbar.refresh_back_forward(self.ui.pages.can_home)
-        self.choosed_category = widget.get_children()[0].get_children()[1].get_text()
+        self.choosed_category = self.ui.categories_button_dict[widget]
         self.category_infos = self.ui.categories_dict[self.choosed_category]
         self.ui.pages.change_page(1)
-        self.ui.categorie_icon.set_from_icon_name(self.category_infos[0], 1)
+        self.ui.categorie_icon.set_from_icon_name(self.category_infos[0], Gtk.IconSize.LARGE_TOOLBAR)
         self.ui.categorie_label.set_text(self.choosed_category)
-        self.actual_category = self.choosed_category
-        self.append_packages_call(self.category_infos[1], [], self.ui.apps_all.model)
+        self.actual_category = self.ui.categories_button_dict[widget]
+        self.append_packages_call(self.choosed_category, [], self.ui.apps_all.model, self.category_infos[2])
     
     def statusbox_combo_changed(self, widget):
-        if widget.get_active() == 0:
-            self.search(self.ui.search_pkg.search_entry.get_text(), 20)
-        else:
-            self.search(self.ui.search_pkg.search_entry.get_text(), False)
+        if self.active_for_search:
+            if widget.get_active() == 0:
+                self.search(self.ui.search_pkg.search_entry.get_text(), 20)
+            else:
+                self.search(self.ui.search_pkg.search_entry.get_text(), False)
 
     ###########################################################
     # Functions related to the "Available" section
@@ -161,11 +183,11 @@ class LscControl:
         self.ui.no_found_box.set_visible(False)
         self.ui.apps_scrolled.set_visible(True)
         self.ui.apps_all.set_model(self.ui.apps_all.model)
-        self.actual_category = _("All")
+        self.actual_category = "packages"
         self.section = self.ui.categories_dict[self.actual_category]
         self.searched = self.ui.search_pkg.search_entry.get_text()
         self.ui.search_pkg.clean_text()
-        self.append_packages_call("allpkgs", [], self.ui.apps_all.model)
+        self.append_packages_call("packages", [], self.ui.apps_all.model, self.section[2])
         self.ui.search_pkg.set_searching_text(self.searched)
         self.search(self.searched, 20)
         self.choosed_category = self.ui.categorie_label.get_text()
@@ -174,10 +196,10 @@ class LscControl:
         '''Handle the change of section'''
         self.choosed_category = self.ui.categories_model[path[0]]
         self.ui.pages.change_page(1)
-        self.ui.categorie_icon.set_from_icon_name(self.choosed_category[1], 1)
+        self.ui.categorie_icon.set_from_icon_name(self.choosed_category[1], Gtk.IconSize.LARGE_TOOLBAR)
         self.ui.categorie_label.set_text(self.choosed_category[0])
         self.actual_category = self.choosed_category[0]
-        self.append_packages_call(self.choosed_category[2], [], self.ui.apps_all.model)
+        self.append_packages_call(self.choosed_category[2], [], self.ui.apps_all.model, self.choosed_category[2])
     
     def on_selected_available(self, widget):
         '''Show the bottom box with the message'''
@@ -185,9 +207,14 @@ class LscControl:
             widget = self.ui.apps_all.model
         if widget.get_cursor()[0] != None:
             self.pkg = widget.get_model()[widget.get_cursor()[0]]
-            self.pkg_selected = (self.pkg[3], self.pkg[0], self.pkg[1], self.pkg[4])
-            self.ui.apps_message.package_name.set_text("'%s' " % self.pkg_selected[0]+_(" package selected"))
-            self.ui.installed_message.package_name.set_text("'%s' " % self.pkg_selected[0]+_(" package selected"))
+            self.pkg_selected = (
+            self.pkg[3],
+            self.pkg[0],
+            self.pkg[1],
+            self.pkg[4]
+            )
+            self.ui.apps_message.package_name.set_text(_("Selected package ")+"'%s' " % self.pkg_selected[0])
+            self.ui.installed_message.package_name.set_text(_("Selected package ")+"'%s' " % self.pkg_selected[0])
             if not self.pkg_selected[3] == Gtk.STOCK_YES:
                 if self.pkg_selected[0] in self.marked_as_install:
                     print("this app is marked as install")
@@ -239,6 +266,8 @@ class LscControl:
     #
     def define_icon(self, pkg):
         '''Return the icon of the package'''
+        if control.controller.render_icons == False:
+            return "deb"
         if pkg != None:
             if self.theme.has_icon(pkg):
                 return pkg
@@ -247,72 +276,60 @@ class LscControl:
         else:
             return "deb"
         
-    def append_packages_call(self, category="allpkgs", status=[apt_pkg.CURSTATE_NOT_INSTALLED], model=None):
+    def append_packages_call(self, category=[], status=[apt_pkg.CURSTATE_NOT_INSTALLED], model=None, showboth=False):
         '''Append the packages in the given section to the given model, default non-installed'''
-        self.packages.sort()
         model.clear()
-        self.call = threadingops.append_packages(self, category, status, model)
+        self.call = threadingops.append_packages(self, category, status, model, showboth)
         self.call.run()
     
     def search(self, string, show_few_results):
         '''Search the string in the model of the given page'''
         self.smart_mode = False # false by default
-        self.smart_dict = {
-        False: _("Case Insensitive"),
-        True: _("Case Sensitive")
-        }
-        self.current_page = self.ui.pages.get_current_page()
+        self.was_searching = True
+        self.current_page = self.ui.pages.get_page()
         self.ui.no_found_box.set_visible(False)
         self.ui.no_found_labelbox.set_visible(False)
         self.ui.apps_scrolled.set_visible(True)
         self.ui.installed_scrolled.set_visible(True)
         self.ui.no_installed_found.set_visible(False)
+        for items in string: # if there is at least one character uppercase the research is case-sensitive
+            if items.isupper():
+                self.smart_mode = True
         if self.current_page == 0:
             self.ui.pages.can_home = True
             self.ui.toolbar.refresh_back_forward(self.ui.pages.can_home)
             self.ui.pages.change_page(1)
             if len(self.ui.apps_all.model) == 0:
-                self.actual_category = _("All")
-                self.append_packages_call("allpkgs", [], self.ui.apps_all.model)
-            self.search(string, 20)
+                self.actual_category = "packages"
+                self.append_packages_call("packages", [], self.ui.apps_all.model, False)
+            self.search(string, show_few_results)
         else:
             if string != "":
-                for items in string:
-                    if items.isupper():
-                        self.smart_mode = True # if there is at least one character uppercase the research is case-sensitive
                 if self.current_page == 2:
-                    self.installed_model_search = Gtk.ListStore(str, str, int, str, str, int, Pango.EllipsizeMode)
-                    if show_few_results:
-                        self.ui.statusbox.combo.set_visible(True)
-                        self.ui.statusbox.combo.set_active(0)
-                        x = 0
-                        for items in self.ui.apps_installed.model:
-                            if show_few_results == x:
-                                if len(self.installed_model_search) < 20:
-                                    x = 0
-                                else:
-                                    break
-                            else:
-                                if self.smart_mode:
-                                    if string in items[0]+items[3]:
-                                         self.installed_model_search.append([items[0], items[1], items[2], items[3], items[4], items[5], items[6]])
-                                else:
-                                    if string.lower() in items[0].lower(): # lower() => no case-sensitive
-                                        self.installed_model_search.append([items[0], items[1], items[2], items[3], items[4], items[5], items[6]])
-                                x += 1
+                    self.installed_model_search.clear()
+                    if not type(show_few_results) == int:
+                        show_few_results = len(self.ui.apps_installed.model)
                     else:
                         self.ui.statusbox.combo.set_visible(True)
-                        self.ui.statusbox.combo.set_active(1)
-                        for items in self.ui.apps_installed.model:
-                            if self.smart_mode:
-                                if string in items[0]+items[3]:
-                                     self.installed_model_search.append([items[0], items[1], items[2], items[3], items[4], items[5], items[6]])
-                            else:
-                                if string.lower() in items[0].lower(): # lower() => no case-sensitive
-                                    self.installed_model_search.append([items[0], items[1], items[2], items[3], items[4], items[5], items[6]])
+                        self.active_for_search = False
+                        self.ui.statusbox.combo.set_active(0)
+                        self.active_for_search = True
+                    x = 0
+                    y = 0
+                    while (x != show_few_results) and (y < len(self.ui.apps_installed.model)):
+                        path = Gtk.TreePath.new_from_string("%s" % y)
+                        items = self.ui.apps_installed.model[path]
+                        if self.smart_mode:
+                            if string in items[0]+items[3]:
+                                 self.installed_model_search.append(list(items))
+                                 x += 1
+                        else:
+                            if string.lower() in items[0].lower()+items[3].lower(): # lower() => no case-sensitive
+                                self.installed_model_search.append(list(items))
+                                x += 1
+                        y += 1
                     self.ui.apps_installed.set_model(self.installed_model_search)
                     self.ui.categorie_label.set_text(_("Searching in Installed"))
-                    self.ui.pkgs_count.set_text("%s %s (%s)" % (len(self.installed_model_search), _("packages matching"), self.smart_dict[self.smart_mode]))
                     self.current_installed_model = self.installed_model_search
                     if len(self.current_installed_model) == 0:
                         self.ui.installed_scrolled.set_visible(False)
@@ -322,42 +339,34 @@ class LscControl:
                         self.ui.no_installed_found.set_visible(False)
                 else:
                     self.section = self.ui.categories_dict[self.actual_category]
-                    self.apps_model_search = Gtk.ListStore(str, str, int, str, str, int, Pango.EllipsizeMode)
-                    if show_few_results:
-                        self.ui.statusbox.combo.set_visible(True)
-                        self.ui.statusbox.combo.set_active(0)
-                        x = 0
-                        for items in self.ui.apps_all.model:
-                            if show_few_results == x:
-                                if len(self.apps_model_search) < show_few_results:
-                                    x = 0
-                                else:
-                                    break
-                            else:
-                                if self.smart_mode:
-                                    if string in items[0]+items[3]:
-                                         self.apps_model_search.append([items[0], items[1], items[2], items[3], items[4], items[5], items[6]])
-                                else:
-                                    if string.lower() in items[0].lower(): # lower() => no case-sensitive
-                                        self.apps_model_search.append([items[0], items[1], items[2], items[3], items[4], items[5], items[6]])
-                                x += 1
+                    self.apps_model_search.clear()
+                    if not type(show_few_results) == int:
+                        show_few_results = len(self.ui.apps_all.model)
                     else:
                         self.ui.statusbox.combo.set_visible(True)
-                        self.ui.statusbox.combo.set_active(1)
-                        for items in self.ui.apps_all.model:
-                            if self.smart_mode:
-                                if string in items[0]+items[3]:
-                                     self.apps_model_search.append([items[0], items[1], items[2], items[3], items[4], items[5], items[6]])
-                            else:
-                                if string.lower() in items[0].lower(): # lower() => no case-sensitive
-                                    self.apps_model_search.append([items[0], items[1], items[2], items[3], items[4], items[5], items[6]])
+                        self.active_for_search = False
+                        self.ui.statusbox.combo.set_active(0)
+                        self.active_for_search = True
+                    x = 0
+                    y = 0
+                    while (x != show_few_results) and (y < len(self.ui.apps_all.model)):
+                        path = Gtk.TreePath.new_from_string("%s" % y)
+                        items = self.ui.apps_all.model[path]
+                        if self.smart_mode:
+                            if string in items[0]+items[3]:
+                                 self.apps_model_search.append(list(items))
+                                 x += 1
+                        else:
+                            if string.lower() in items[0].lower()+items[3].lower(): # lower() => no case-sensitive
+                                self.apps_model_search.append(list(items))
+                                x += 1
+                        y += 1
                     self.ui.apps_all.set_model(self.apps_model_search)
-                    self.ui.categorie_icon.set_from_icon_name(self.section[0], 1)
-                    self.ui.categorie_label.set_text(_("Searching in"+" %s" % self.actual_category))
-                    self.ui.pkgs_count.set_text("%s %s (%s)" % (len(self.apps_model_search), _("packages matching"), self.smart_dict[self.smart_mode]))
+                    self.ui.categorie_icon.set_from_icon_name(self.section[0], Gtk.IconSize.LARGE_TOOLBAR)
+                    self.ui.categorie_label.set_text(_("Searching in")+" %s" % self.section[1])
                     self.current_apps_model = self.apps_model_search
                     if len(self.current_apps_model) == 0:
-                        if self.actual_category != _("All"):
+                        if self.actual_category != "packages":
                             self.ui.apps_scrolled.set_visible(False)
                             self.ui.no_found_box.set_visible(True)
                         else:
@@ -376,10 +385,11 @@ class LscControl:
                 else:
                     self.section = self.ui.categories_dict[self.actual_category]
                     self.ui.apps_all.set_model(self.ui.apps_all.model)
-                    self.ui.categorie_icon.set_from_icon_name(self.section[0], 1)
-                    self.ui.categorie_label.set_text(self.actual_category)
+                    self.ui.categorie_icon.set_from_icon_name(self.section[0], Gtk.IconSize.LARGE_TOOLBAR)
+                    self.ui.categorie_label.set_text(self.section[1])
                     self.ui.pkgs_count.set_text("%s " % len(self.ui.apps_all.model) +_("packages listed"))
                     self.current_apps_model = self.ui.apps_all.model
+                self.was_searching = False
                 self.ui.statusbox.combo.set_visible(False)
     
     ###########################################################
@@ -395,33 +405,36 @@ class LscControl:
         self.ui.search_pkg.set_sensitive(False)
         self.ui.apps_basket.model.clear()
         self.total_download = 0
+        self.total_install = 0
         self.depends = []
         for items in sorted(self.marked_as_install):
             self.get_pkg_depends(items)
             self.info = self.depcache.get_candidate_ver(self.cache[items])
             self.total_download += self.info.size
-            self.ui.apps_basket.model.append([items.capitalize(), apt_pkg.size_to_str(self.info.size), self.info.ver_str])
+            self.total_install += self.info.installed_size
+            self.ui.apps_basket.model.append([items.capitalize(), apt_pkg.size_to_str(self.info.size), apt_pkg.size_to_str(self.info.installed_size), self.info.ver_str])
             for item in sorted(self.depends):
                 if not self.cache[item].current_state == apt_pkg.CURSTATE_INSTALLED:
                     if not self.value_in_model(item, self.ui.apps_basket.model):
                         self.info = self.depcache.get_candidate_ver(self.cache[item])
                         if self.info == None:
-                            self.ui.apps_basket.model.append([" "*4+item+_(" (requested by ")+items+")", _("unknown"), _("unknown")])
+                            self.ui.apps_basket.model.append([" "*4+item+_(" (requested by ")+items+")", _("unknown"), -("unknown"), _("unknown")])
                         else:
                             self.total_download += self.info.size
-                            self.ui.apps_basket.model.append([" "*4+item+_(" (requested by ")+items+")", apt_pkg.size_to_str(self.info.size), self.info.ver_str])
+                            self.total_install += self.info.installed_size
+                            self.ui.apps_basket.model.append([" "*4+item+_(" (requested by ")+items+")", apt_pkg.size_to_str(self.info.size), apt_pkg.size_to_str(self.info.installed_size), self.info.ver_str])
         if len(self.ui.apps_basket.model) == 0:
             self.ui.riepilogue_label.set_text(_("Put some apps in the basket to install them"))
             self.ui.install_pkgs.set_sensitive(False)
             self.ui.remove_mai_button.set_sensitive(False)
             self.ui.basket_radio.label.set_text(_("Apps Basket"))
         else:
-            self.ui.riepilogue_label.set_text("%s %s, %s %s" % (len(self.marked_as_install), _("package marked"), apt_pkg.size_to_str(self.total_download), _("to download")))
+            self.ui.riepilogue_label.set_text("%s %s, %s %s, %s %s" % (len(self.marked_as_install), _("package marked"), apt_pkg.size_to_str(self.total_download), _("to download"), apt_pkg.size_to_str(self.total_install), _("to install")))
             self.ui.install_pkgs.set_sensitive(True)
             self.ui.remove_mai_button.set_sensitive(True)
             self.ui.basket_radio.label.set_text(_("Apps Basket")+" (%s)" % len(self.marked_as_install))
         self.on_selected_available(self.ui.apps_all)
-        self.ui.categorie_icon.set_from_icon_name("applications-other", 1)
+        self.ui.categorie_icon.set_from_icon_name("applications-other", Gtk.IconSize.LARGE_TOOLBAR)
         self.ui.categorie_label.set_text(_("Apps Basket"))
         self.ui.pkgs_count.set_text("%s " % len(self.ui.apps_basket.model)+_("packages"))
         self.ui.statusbox.combo.set_visible(False)
@@ -436,25 +449,14 @@ class LscControl:
     def get_pkg_depends(self, pkgname):
         '''Get the provided version of the given package'''
         self.list2 = []
-        if not self.cache[pkgname].version_list == []:
-            self.version = self.depcache.get_candidate_ver(self.cache[pkgname])
-            try:
-                self.depends_list = self.version.depends_list_str["Depends"]
-            except KeyError:
-                self.depends_list = []
-        
-        elif not self.cache[pkgname].provides_list == []:
-            for pkgs in self.cache[pkgname].provides_list:
-                self.version = pkgs[2]
-                try:
-                    self.depends_list = self.version.depends_list_str["Depends"]
-                except KeyError:
-                    self.depends_list = []
+        self.depends_list = threadingops.getdeps(pkgname)
+        if self.depends_list == [u'']:
+            self.depends_list = []
         for items in self.depends_list:
-            if not items[0][0] in self.depends:
-                if self.cache[items[0][0]].current_state != 6:
-                    self.list2.append(items[0][0])
-                    self.depends.append(items[0][0])
+            if not items in self.depends:
+                if self.cache[items].current_state != 6:
+                    self.list2.append(items)
+                    self.depends.append(items)
         for items in self.list2:
             # Recursive ;-)
             self.get_pkg_depends(items)
@@ -476,13 +478,13 @@ class LscControl:
     #   
     def back_home(self, widget):
         '''Back home, sweet home'''
-        self.ui.search_pkg.on_focus_out(self.ui.search_pkg.search_entry, None)
         self.ui.search_pkg.set_sensitive(True)
         self.ui.set_focus(self.ui.toolbar.settings)
-        self.ui.categorie_icon.set_from_icon_name("stock_down", 1)
+        self.ui.categorie_icon.set_from_icon_name("stock_down", Gtk.IconSize.LARGE_TOOLBAR)
         self.ui.categorie_label.set_text(_("Available Categories"))
         self.choosed_page = 0
         self.ui.pkgs_count.set_text(_("Choose a category to start"))
+        self.ui.apps_all.model.clear()
         self.ui.pages.back(None, self.ui.toolbar)
         self.ui.statusbox.combo.set_visible(False)
     
@@ -499,18 +501,23 @@ class LscControl:
     
     def on_more_info(self, widget, status):
         '''Get more info on the selection'''
+        self.ui.toolbar.back.set_sensitive(True)
         self.candidate = self.depcache.get_candidate_ver(self.cache[self.pkg_selected[0]])
-        self.infos.lookup(self.candidate.file_list[0])
+        if self.cache[self.pkg_selected[0]].current_state == apt_pkg.CURSTATE_INSTALLED:
+            inst = True
+        else:
+            inst = False
         self.setup_infos(
         self.pkg_selected[0],
         self.ui.pages,
         self.pkg_selected[2],
-        "\n".join([self.pkg_selected[1].split("\n")[0], self.infos.short_desc]),
-        self.infos.long_desc.replace("\n ", "\n"),
+        "\n".join([self.pkg_selected[1].split("\n")[0], threadingops.getshortdesc(self.pkg_selected[0])]),
+        threadingops.getdesc(self.pkg_selected[0]).replace("\n ", "\n"),
         (apt_pkg.size_to_str(self.candidate.size),
         apt_pkg.size_to_str(self.candidate.installed_size)),
         self.candidate.ver_str,
-        self.ui.pages.get_current_page()
+        self.ui.pages.get_current_page(),
+        inst
         )
     
     def app_item_activated(self, widget, path, column, inst_rem):
@@ -552,8 +559,25 @@ class LscControl:
         '''Open the software properties'''
         subprocess.call(["/usr/bin/software-properties-gtk"])
     
-    def setup_infos(self, name, pages, icon, title, description, size, version, last_page):
+    def download_review(self, widget):
+        name = self.pkg_selected[0]
+        self.ui.appsinfo.check_reviews.set_visible(False)
+        for widget in self.ui.appsinfo.reviews_box.get_children():
+            self.ui.appsinfo.reviews_box.remove(widget)
+        self.tmp_review_label = self.ui.appsinfo.screendesc.add_icon_label("<b>"+_("Reviews")+"</b>", "stock_about")
+        self.ui.appsinfo.reviews_box.pack_start(self.tmp_review_label, False, False, 0)
+        threadingops.download_review(name, control.controller.reviews_path+"/")
+        threadingops.parse_review(name, control.controller.reviews_path+"/", self.ui.appsinfo.reviews_box)
+        self.ui.appsinfo.reviews_box.show_all()
+    
+    def setup_infos(self, name, pages, icon, title, description, size, version, last_page, installed):
         '''Setup the infos dialog'''
+        if installed:
+            self.ui.statusbox.installed.set_from_stock(Gtk.STOCK_YES, 1)
+        self.ui.appsinfo.scrot.set_from_stock("", 1);
+        self.ui.appsinfo.check_reviews.set_visible(True)
+        self.ui.appsinfo.reviews_box.set_visible(False)
+        self.ui.statusbox.combo.set_visible(False)
         self.last_page = last_page
         self.last_page_label = self.ui.categorie_label.get_text()
         self.last_page_icon = self.ui.categorie_icon.get_icon_name()[0]
@@ -561,28 +585,22 @@ class LscControl:
         self.ui.appsinfo.icon.set_from_icon_name(icon, 6)
         self.ui.appsinfo.title.set_markup("<b><big>"+title.split("\n")[0]+"</big></b>")
         self.ui.appsinfo.desc.set_text(title.split("\n")[-1])
-        self.ui.appsinfo.desctext.set_text(description.replace("\n.", "\n"))
-        self.ui.appsinfo.details.to_download.set_text(_("Download Size:")+" %s" % size[0])
-        self.ui.appsinfo.details.installed.set_text(_("Installed Size:")+" %s" % size[1])
-        self.ui.appsinfo.details.version.set_text(_("Version:")+" %s (%s)" % (version, name))
-        self.ui.categorie_icon.set_from_icon_name("stock_help", 1)
+        description_formatted = description.replace("\n.", "\n")
+        #This is needed to remove the double short description
+        description_formatted = description_formatted.replace(title.split("\n")[-1], "")
+        self.ui.appsinfo.desctext.set_text(description_formatted.strip())
+        self.ui.appsinfo.details.to_download.set_markup("<b>"+_("Download Size:")+"</b>"+" %s" % size[0])
+        self.ui.appsinfo.details.installed.set_markup("<b>"+_("Installed Size:")+"</b>"+" %s" % size[1])
+        self.ui.appsinfo.details.version.set_markup("<b>"+_("Version:")+"</b>"+" %s (%s)" % (version, name))
+        self.ui.categorie_icon.set_from_icon_name("stock_help", Gtk.IconSize.LARGE_TOOLBAR)
         self.ui.categorie_label.set_text(_("Infos on")+" %s" % title.split("\n")[0])
         self.ui.appsinfo.scrot_button.set_visible(False)
         if control.controller.show_scrot == True:
-            if os.path.isfile(os.path.join("/usr/lib/lubuntu-software-center/lubuntu-software-center-download-scrot")):
-                self.response = os.popen(" ".join(["python", "/usr/lib/lubuntu-software-center/lubuntu-software-center-download-scrot", name, control.controller.screenshots_path+"/"])).read()
-            else:
-                self.response = os.popen(" ".join(["python", "scripts/lubuntu-software-center-download-scrot", name, control.controller.screenshots_path+"/"])).read()
-            self.ui.appsinfo.scrot_button.set_visible(True)
-            if os.path.exists("/".join([control.controller.screenshots_path, name])):
-                self.scrot_buf = GdkPixbuf.Pixbuf.new_from_file_at_size("/".join([control.controller.screenshots_path, name]), 300, 300)
-                self.ui.appsinfo.scrot.set_from_pixbuf(self.scrot_buf)
-            else:
-                self.ui.appsinfo.scrot_button.set_visible(False)
+            threadingops.download_screenshot(name, control.controller.screenshots_path+"/", self.ui.appsinfo.scrot, self.ui.appsinfo.scrot_button)
         self.package = name
         self.ui.pages.change_page(4)
     
-    def maximize_screenshot(self, widget):
+    def maximize_screenshot(self, widget, event):
         self.dialog = self.ui.scrot_dialog("/".join([control.controller.screenshots_path, self.package]), self.package.capitalize()+" screenshot")
     
     def update_cache(self, widget):
@@ -606,27 +624,34 @@ class LscControl:
         apt_pkg.init()
         self.cache = apt_pkg.Cache()
         self.depcache = apt_pkg.DepCache(self.cache)
-        self.infos = apt_pkg.PackageRecords(self.cache)
         control.__init__()
         self.aid = control.controller.app_install_directory
         self.marked_as_install = []
         self.theme = Gtk.IconTheme.get_default()
         self.theme.append_search_path("/usr/share/app-install/icons/")
-        self.ui.apps_all.model.clear()
-        self.ui.apps_installed.model.clear()
         self.current_apps_model = self.ui.apps_all.model
         self.current_installed_model = self.ui.apps_installed.model
         self.refresh_app_basket()
-        self.back_home(None)
         self.ui.apps_all.set_model(self.ui.apps_all.model)
         self.ui.apps_installed.set_model(self.ui.apps_installed.model)
         self.ui.apps_message.set_visible(False)
         self.ui.installed_message.set_visible(False)
         self.ui.toolbar.set_style(3)
         self.packages = []
-        self.refresh = threadingops.refresh_system(self)
-        self.refresh.run()
-        self.check_internet()
+        if (not self.startup) and (self.ui.pages.get_page() in [1, 2]):
+            if self.ui.pages.get_page() == 1:
+                self.get_func()
+                if self.choosed_category == "fonts":
+                    showboth = True
+                else: showboth = False
+                self.append_packages_call(self.choosed_category, [], self.ui.apps_all.model, showboth)
+            if self.ui.pages.get_page() == 2:
+                self.installed_func()
+        elif self.startup:
+            self.back_home(None)
+        if control.controller.check_internet:
+            self.check_internet()
+        self.startup = False
     
     def append_packages_appending(self, items,  status, status_dict, model, (cur, tot)):
         '''Called by threadingops.append_packages'''
@@ -634,8 +659,8 @@ class LscControl:
             self.pkg_in_cache = self.cache[items[1]]
             if not self.pkg_in_cache.current_state in status:
                 self.item = [
-                u'\n'.join([items[0].replace("&", "and"), items[2].replace("&", "and")]),
-                self.define_icon(items[3]),
+                u'\n'.join([items[0].replace("&", "and"), items[3].replace("&", "and")]),
+                self.define_icon(items[4]),
                 3,
                 items[1],
                 status_dict[self.pkg_in_cache.current_state],
